//
//  NetworkHelper.h
//  ASP51NV2SDK_SDK
//
//  Created by Yasutaka Oshiro on 2019/04/23.
//  Copyright © 2019年 Robin. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <CFNetwork/CFNetwork.h>
@interface NetworkHelper : NSObject <NSStreamDelegate>

typedef NS_ENUM(NSUInteger, StatusCode) {
    StatusCodeUnknown = -1,
    StatusCodeSuccess = 0,
    AlreadyTCPConnected,
    NotTCPConnected,
    CanNotSendData,
};


// DeviceNetworkInfo&Status
@property(nonatomic, retain, readonly)NSString *IP;
@property(nonatomic, retain, readonly)NSString *subnet;
@property(nonatomic, retain, readonly)NSString *gateway;
@property(nonatomic, retain, readonly)NSString *DNS;
@property(nonatomic, retain, readonly)NSString *MACAddress;
@property(nonatomic, assign, readonly)NSString *DHCP;

// UDPStatus
@property(nonatomic, assign)BOOL isConnected;

@property(atomic, assign)id delegate;

// PublicMethod
// TCP
- (StatusCode)connectServerWithIP:(NSString *)IP remoteport:(int)port;
- (StatusCode)disconnect;
- (StatusCode)sendData:(NSData *)data length:(int)length;

// UDP
- (BOOL)searchDevice;
- (BOOL)stopSearch;
- (BOOL)setDHCPForMACAddress:(NSString *)MACAddress;
- (BOOL)setDHCPForMACAddress:(NSString *)MACAddress
                          IP:(NSString *)IP
                      subnet:(NSString *)subnet
                     gateway:(NSString *)gateway
                   DNSServer:(NSString *)DNSServer;
@end

@protocol NetworkHelperDelegate <NSObject>
// TCP
- (void)NetworkHelperTCPOnDisconnect:(NetworkHelper *)networkHepler;
- (void)NetworkHelperTCPOnConnected:(NetworkHelper *)networkHepler;
- (void)NetworkHelper:(NetworkHelper *)networkHepler onReceive:(NSData *)data;
- (void)NetworkHelper:(NetworkHelper *)networkHepler onErrorReceive:(NSError *)err;

// UDP
- (void)NetworkHelper:(NetworkHelper *)networkHepler onSearchingUDPReceiveIP:(NSString *)IP isFinish:(BOOL)isFinish;
- (void)NetworkHelper:(NetworkHelper *)networkHepler onSearchingDeviceInfoReceive:(NSArray *)infoArray;
@end
