//  SettingsPowerController.m

#import "OutputPowerController.h"
#import "Utils.h"
#import <ASP51NV2SDK/ASP51NV2SDK.h>

#define DF_READTIME_MIN 10
#define DF_READTIME_MAX 2550

@interface OutputPowerController () <ASP51NV2Delegate>
{
    int powerAnt;
    NSMutableArray *arrPowerRange;
}

@property (nonatomic,retain) IBOutlet UITextField *txtFieldOutPwrAnt1;
- (IBAction)setOutputPowerButtonAction:(id)sender;
@end

@implementation OutputPowerController

#pragma mark - Lifecycle
- (void)viewDidLoad
{
    [super viewDidLoad];
    [self.tableView reloadData];
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    
    if(arrPowerRange == nil)
        arrPowerRange = [[NSMutableArray alloc]init];
    
    [arrPowerRange removeAllObjects];
    
    [ASP51NV2 sharedInstance].delegate = self;
    
    [self performSelector:@selector(onTickGetOuputPower) withObject:nil afterDelay:.2f];
    [Utils showLoadingView:@"Check Settings" timeOut:df_TIMEOUT_DEFAULT];
}

- (void)viewWillDisappear:(BOOL)animated
{
    [super viewWillDisappear:animated];
    [ASP51NV2 sharedInstance].delegate = nil;
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
}

#pragma mark - IBAction
- (IBAction)setOutputPowerButtonAction:(id)sender
{
    [self updateTxValue];
    [Utils showLoadingView:@"Change OutputPower" timeOut:df_TIMEOUT_DEFAULT];
    [[ASP51NV2 sharedInstance] setOutputPowerLevel:powerAnt];
}

#pragma mark - PrivateMethod
- (void)onTickGetOuputPower
{
//    zzz
//    NSError *error = [[ASP51NV2SDK sharedInstance] getOutputPowerLevelForMultiAntenna];
//    if( error ){
//        NSLog(@"%@\n code = %ld\n%@", NSStringFromSelector(_cmd), error.code, error.userInfo);
//    }
    [[ASP51NV2 sharedInstance] getOutputPowerLevel];
}

- (void)updateTxValue
{
    powerAnt = [[_txtFieldOutPwrAnt1 text]intValue];
}

- (void)updateValue
{
    [_txtFieldOutPwrAnt1 setText:[NSString stringWithFormat:@"%d",powerAnt]];
}

#pragma mark - ASP51NV2SDK Delegate
- (void)ASP51NV2:(ASP51NV2 *)ASP51NV2 receivedOutputPowerLevel:(uint8_t)outputPowerLevel executionStatus:(ASP51NV2ExecutionStatus)statusCode
{
    if (statusCode == ASP51NV2ExecutionStatusSuccess) {
        [Utils hiddenLoadingView];
        powerAnt = outputPowerLevel;
        dispatch_async(dispatch_get_main_queue(),^{
            [self updateValue];
        });
    } else {
        if (statusCode == ASP51NV2ExecutionStatusOtherCommandExecuted) {
            
        } else {
            [Utils hiddenLoadingView];
        }
        [Utils showAlert:@"OutPut Power Fail" message:[NSString stringWithFormat:@"%x", statusCode] view:self];
    }
}

- (void)ASP51NV2:(ASP51NV2 *)ASP51NV2 didSetOutputPowerLevelExecutionStatus:(ASP51NV2ExecutionStatus)statusCode
{
    if (statusCode == ASP51NV2ExecutionStatusSuccess) {
        [Utils hiddenLoadingView];
        [Utils showAlert:@"Success" message:@"OutPut Power changed" view:self];
    } else {
        if (statusCode == ASP51NV2ExecutionStatusOtherCommandExecuted) {
            
        } else {
            [Utils hiddenLoadingView];
        }
        [Utils showAlert:@"OutPut Power changed Fail" message:[NSString stringWithFormat:@"%x", statusCode] view:self];
    }
}

- (void)ASP51NV2:(ASP51NV2 *)ASP51NV2 changeNetworkState:(ASP51NV2NetworkState)state error:(NSError *)error
{
    switch (state) {
        case ASP51NV2NetworkStateDisconnected:
            [Utils showAlert:@"Fail" message:@"The network connection is lost." view:self];
            break;
        case ASP51NV2NetworkStateError:
            break;
        default:
            break;
    }
}

- (void)ASP51NV2:(ASP51NV2 *)ASP51NV2 receivedExecutionStatus:(ASP51NV2ExecutionStatus)statusCode
{
    [Utils showAlert:@"Error" message:[NSString stringWithFormat:@"%x", statusCode] view:self];
}
@end
