#import "RFIDTvController.h"
#import <ASP51NV2SDK/ASP51NV2SDK.h>
#import "Utils.h"

@interface RFIDTvController ()<ASP51NV2Delegate>
@property (weak, nonatomic) IBOutlet UILabel   *labelSession;
@property (weak, nonatomic) IBOutlet UILabel   *labelMode;
@property (weak, nonatomic) IBOutlet UILabel   *labelSearch;
@property (weak, nonatomic) IBOutlet UILabel   *labelRegion;
@end


@implementation RFIDTvController

#pragma mark - Lifecycle
- (void)viewDidLoad
{
    [super viewDidLoad];   
}

- (void)viewWillAppear:(BOOL)animated
{
    [ASP51NV2 sharedInstance].delegate = self;
    [Utils showLoadingView:@"Check Settings" timeOut:df_TIMEOUT_DEFAULT];
    
    //OnSession
    [self performSelector:@selector(onTickGetSession)     withObject:nil afterDelay:.1f];
    
    //Mode
    [self performSelector:@selector(onTickGetMode)     withObject:nil afterDelay:.3f];
    
    //Search
    [self performSelector:@selector(onTickGetSearch)     withObject:nil afterDelay:.5f];
    
    //Region
    [self performSelector:@selector(onTickGetRegion) withObject:nil afterDelay:.7f];
    
    
}

- (void)viewWillDisappear:(BOOL)animated
{
    [ASP51NV2 sharedInstance].delegate = nil;
}

#pragma mark - PrivateMethod
- (void)onTickGetSession
{
    [[ASP51NV2 sharedInstance] getSession];
}

- (void)onTickGetMode
{
    [[ASP51NV2 sharedInstance] getRFMode];
}

- (void) onTickGetSearch
{
    [[ASP51NV2 sharedInstance] getSearchMode];
}

- (void)onTickGetRegion
{
    [[ASP51NV2 sharedInstance] getRegion];
}

#pragma mark - ASP51NV2SDK Delegate
- (void)ASP51NV2:(ASP51NV2 *)ASP51NV2 receivedRegion:(ASP51NV2RegionType)region executionStatus:(ASP51NV2ExecutionStatus)statusCode
{
    if (statusCode == ASP51NV2ExecutionStatusSuccess) {
        [Utils hiddenLoadingView];
        NSString *sRegion = @"--";
        switch (region) {
            case ASP51NV2RegionTypeFccPart_15_247:
                sRegion = @"Fcc Part";
                break;
            case ASP51NV2RegionTypeHongKong_920_925_MHZ:
                sRegion = @"HONGKONG";
                break;
            case ASP51NV2RegionTypeTaiWan_922_928_MHZ:
                sRegion = @"Taiwai";
                break;
            case ASP51NV2RegionTypeEtsiEN_302_208_V1_4_1:
                sRegion = @"Etsi En";
                break;
            case ASP51NV2RegionTypeKorea_917_921_MHZ:
                sRegion = @"Korea";
                break;
            case ASP51NV2RegionTypeMalaysia_919_923_MHZ:
                sRegion = @"Malaysia";
                break;
            case ASP51NV2RegionTypeChina_920_925_MHZ:
                sRegion = @"China";
                break;
            case ASP51NV2RegionTypeSouthAfrica_915_919_MHZ:
                sRegion = @"South Africa";
                break;
            case ASP51NV2RegionTypeBrazil_902_907_AND_915_928_MHZ:
                sRegion = @"Brazil";
                break;
            case ASP51NV2RegionTypeThailand_920_925_MHZ:
                sRegion = @"Thailand";
                break;
            case ASP51NV2RegionTypeSingapore_920_925_MHZ:
                sRegion = @"Singapore";
                break;
            case ASP51NV2RegionTypeAustralia_920_926_MHZ:
                sRegion = @"Australia";
                break;
            case ASP51NV2RegionTypeIndia_865_867_MHZ:
                sRegion = @"India";
                break;
            case ASP51NV2RegionTypeUruguay_916_928_MHZ:
                sRegion = @"Uruguay";
                break;
            case ASP51NV2RegionTypeVietnam_920_925_MHZ:
                sRegion = @"Vietnam";
                break;
            case ASP51NV2RegionTypeIsrael_915_917_MHZ:
                sRegion = @"Israel";
                break;
            case ASP51NV2RegionTypePhilippines_918_920_MHZ:
                sRegion = @"Philippines";
                break;
            case ASP51NV2RegionTypeIndonesia_923_925_MHZ:
                sRegion = @"Indonesia";
                break;
            case ASP51NV2RegionTypeNewzealand_921P5_928_MHZ:
                sRegion = @"New Zealand";
                break;
            case ASP51NV2RegionTypeJapan_916_921_MHZ_NO_LBT:
                sRegion = @"Japan";
                break;
            case ASP51NV2RegionTypePeru_916_928_MHZ:
                sRegion = @"Peru";
                break;
            case ASP51NV2RegionTypeRussia_916_921_MHZ:
                sRegion = @"Russia";
                break;
            case ASP51NV2RegionTypeCustom:
                sRegion = @"Custom";
                break;
            default:
                return;
        }
        dispatch_async(dispatch_get_main_queue(),^{
            self.labelRegion.text = sRegion;
        });
    } else {
        if (statusCode == ASP51NV2ExecutionStatusOtherCommandExecuted) {
            
        } else {
            [Utils hiddenLoadingView];
        }
        [Utils showAlert:@"Region Fail" message:[NSString stringWithFormat:@"%d", statusCode] view:self];
    }
}

- (void)ASP51NV2:(ASP51NV2 *)ASP51NV2 receivedSession:(ASP51NV2SessionType)session executionStatus:(ASP51NV2ExecutionStatus)statusCode {
    if (statusCode == ASP51NV2ExecutionStatusSuccess) {
        [Utils hiddenLoadingView];
        self->_labelSession.text = [NSString stringWithFormat:@"SESSION_S%d",session];
    } else {
        if (statusCode == ASP51NV2ExecutionStatusOtherCommandExecuted) {
            
        } else {
            [Utils hiddenLoadingView];
        }
        [Utils showAlert:@"Session Fail" message:[NSString stringWithFormat:@"%x", statusCode] view:self];
    }
}

- (void)ASP51NV2:(ASP51NV2 *)ASP51NV2 receivedRFMode:(ASP51NV2RFModeType)RFMode executionStatus:(ASP51NV2ExecutionStatus)statusCode
{
    if (statusCode == ASP51NV2ExecutionStatusSuccess) {
        [Utils hiddenLoadingView];
        NSString *string = @"";
        switch (RFMode) {
            case ASP51NV2RFModeType_E0:
                string = @"RFMODE0";
                break;
            case ASP51NV2RFModeType_E1:
                string = @"RFMODE1";
                break;
            case ASP51NV2RFModeType_E2:
                string = @"RFMODE2";
                break;
            case ASP51NV2RFModeType_E3:
                string = @"RFMODE3";
                break;
            case ASP51NV2RFModeType_E4:
                string = @"RFMODE4";
                break;
            default:
                string = @"";
                break;
        }
        dispatch_async(dispatch_get_main_queue(),^{
            self->_labelMode.text = string;
        });
    } else {
        if (statusCode == ASP51NV2ExecutionStatusOtherCommandExecuted) {
            
        } else {
            [Utils hiddenLoadingView];
        }
        [Utils showAlert:@"RfMode Fail" message:[NSString stringWithFormat:@"%d", statusCode] view:self];
    }
}
- (void)ASP51NV2:(ASP51NV2 *)ASP51NV2 receivedSetSearchMode:(ASP51NV2SearchModeType)searchModel executionStatus:(ASP51NV2ExecutionStatus)statusCode
{
    if (statusCode == ASP51NV2ExecutionStatusSuccess) {
        [Utils hiddenLoadingView];
        NSString *string = @"";
        switch (searchModel) {
            case ASP51NV2SearchModeTypeAutoSearch:
                string = @"AUTO_SEARCH";
                break;
            case ASP51NV2SearchModeTypeDualTarget:
                string = @"DUAL_TARGET_UAL_TARGET";
                break;
            case ASP51NV2SearchModeTypeSingleTarget_A_TO_B:
                string = @"SINGLE_TARGET_A_TO_B";
                break;
            case ASP51NV2SearchModeTypeSingleTarget_B_TO_A:
                string = @"SINGLE_TARGET_B_TO_A";
                break;
            default:
                string = @"";
                break;
        }
        dispatch_async(dispatch_get_main_queue(),^{
            self->_labelSearch.text = string;
        });
    } else {
        if (statusCode == ASP51NV2ExecutionStatusOtherCommandExecuted) {
            
        } else {
            [Utils hiddenLoadingView];
        }
        [Utils showAlert:@"SearchMode Fail" message:[NSString stringWithFormat:@"%d", statusCode] view:self];
    }
}

- (void)ASP51NV2:(ASP51NV2 *)ASP51NV2 changeNetworkState:(ASP51NV2NetworkState)state error:(NSError *)error
{
    switch (state) {
        case ASP51NV2NetworkStateDisconnected:
            [Utils showAlert:@"Fail" message:@"The network connection is lost." view:self];
            break;
        case ASP51NV2NetworkStateError:
            break;
        default:
            break;
    }
}

- (void)ASP51NV2:(ASP51NV2 *)ASP51NV2 receivedExecutionStatus:(ASP51NV2ExecutionStatus)statusCode
{
    [Utils showAlert:@"Error" message:[NSString stringWithFormat:@"%x", statusCode] view:self];
}
@end
