//  ReadWriteController.m

#import "ReadWriteController.h"
#import "SelectedTagInfo.h"
#import "Utils.h"
#import <ASP51NV2SDK/ASP51NV2SDK.h>
#import "PhyUtility.h"
@interface ReadWriteController () <UITextFieldDelegate, UITextViewDelegate, ASP51NV2Delegate>

@property (weak, nonatomic) IBOutlet UISegmentedControl *olMode;
@property (weak, nonatomic) IBOutlet UITextField *olAccessPassword;
@property (weak, nonatomic) IBOutlet UITextField *olStartAdress;
@property (weak, nonatomic) IBOutlet UITextField *olLength;
@property (weak, nonatomic) IBOutlet UISegmentedControl *olTargetMemory;
@property (weak, nonatomic) IBOutlet UITextField *olTargetEpc;
@property (weak, nonatomic) IBOutlet UILabel *olDataTitle;
@property (strong, nonatomic) IBOutlet UITextView *textView;

- (IBAction)rightBarButtonItemClicked:(id)sender;
- (IBAction)eTargetMemoryChanged:(id)sender;
- (IBAction)eModeChanged:(id)sender;
@end

@implementation ReadWriteController
#pragma mark - Lifecycle
- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
    }
    return self;
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(keyboardWillShow:) name:UIKeyboardWillShowNotification object:nil];
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(keyboardWillHide:) name:UIKeyboardWillHideNotification object:nil];
    
    SelectedTagInfo *selectTag =  [SelectedTagInfo sharedInstance];
    self.olTargetEpc.text =   selectTag.selectedTagEPC;
    
    [ASP51NV2 sharedInstance].delegate = self;
    self.olAccessPassword.delegate  = self;
    self.olStartAdress.delegate     = self;
    self.olLength.delegate          = self;
    self.olTargetEpc.delegate       = self;
}

- (void)viewWillDisappear:(BOOL)animated
{
    [super viewWillDisappear:YES];
    [[NSNotificationCenter defaultCenter] removeObserver:self name:UIKeyboardWillShowNotification object:nil];
    [[NSNotificationCenter defaultCenter] removeObserver:self name:UIKeyboardWillHideNotification object:nil];
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    self.textView.layer.masksToBounds = YES;
    self.textView.layer.borderWidth = 1;
    self.textView.layer.borderColor = [[UIColor colorWithRed:210 / 255.f green:210 / 255.f blue:215 / 255.f alpha:1] CGColor];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
}

#pragma mark - PrivateMethod
- (NSString *) dataToEpcInteger:(NSData *)data
{
    uint8_t* pData = (uint8_t*)[data bytes];
    uint16_t intData = pData[0] << 8 | pData[1];
    intData = intData >>11;
    return [NSString stringWithFormat:@"%d",intData];
}

- (void)keyboardWillShow:(NSNotification *)notif
{
    if ([self.textView isFirstResponder]) {
        [UIView animateWithDuration:0.1 animations:^{
            if ([UIScreen mainScreen].bounds.size.width > 320) {
                 self.view.frame = CGRectMake(0, -250, self.view.bounds.size.width, self.view.bounds.size.height);
            } else {
                 self.view.frame = CGRectMake(0, -200, self.view.bounds.size.width, self.view.bounds.size.height);
            }
        }];
    }
}

- (void)keyboardWillHide:(NSNotification *)notif
{
    if ([self.textView isFirstResponder]) {
        [UIView animateWithDuration:0.1 animations:^{
            self.view.frame = CGRectMake(0, 0, self.view.bounds.size.width, self.view.bounds.size.height);
        }];
    }
}

#pragma mark - UITextField Delegate
- (BOOL)textFieldShouldReturn:(UITextField *)txtField
{
    [txtField resignFirstResponder];
    return NO;
}

- (void)touchesBegan:(NSSet<UITouch *> *)touches withEvent:(UIEvent *)event
{
    [self.view endEditing:YES];
}

- (BOOL)textView:(UITextView *)textView shouldChangeTextInRange:(NSRange)range replacementText:(NSString *)text{
    if([text isEqualToString:@"\n"]){
        [textView resignFirstResponder];
        return NO;
    }
    return YES;
}

#pragma mark - IBAction
- (IBAction)eModeChanged:(id)sender
{
    if(self.olMode.selectedSegmentIndex == 0) {
        self.navigationItem.title = @"Read";
    } else {
        self.navigationItem.title = @"Write";
    }
}

- (IBAction)rightBarButtonItemClicked:(id)sender
{
    [Utils showLoadingView:@"" timeOut:df_TIMEOUT_DEFAULT];
    if (self.olMode.selectedSegmentIndex == 0) {
        self.textView.text = @"";
    }
    [self.olTargetEpc resignFirstResponder];
    [self.olAccessPassword resignFirstResponder];
    [self.olStartAdress resignFirstResponder];
    [self.olLength resignFirstResponder];
    [self.textView resignFirstResponder];
    NSString  *hexaString = self.olAccessPassword.text;
    NSScanner *pScanner = [NSScanner scannerWithString: hexaString];
    uint32_t  accesspassword;
    [pScanner scanHexInt: &accesspassword];
    
    uint16_t  startAddress = [self.olStartAdress.text intValue];
    uint16_t  dataLength = [self.olLength.text intValue];
    uint8_t   membank =0;
    
    switch(self.olTargetMemory.selectedSegmentIndex) {
        case 0:
            membank = 0;
            break;
        case 1:
            membank = 1;
            break;
        case 2:
            membank = 2;
            break;
        case 3:
            membank = 3;
            break;
    }
    
    NSData *data     = [self.textView.text hexStringToBytes];
    NSData *epcs     = [self.olTargetEpc.text hexStringToBytes];
    
    if(epcs.length == 0) {
        [Utils hiddenLoadingView];
        return;
    }
    
    
    if(self.olMode.selectedSegmentIndex == 0) {
        [[ASP51NV2 sharedInstance] readTagWithAccessPassword:accesspassword EPC:epcs memoryBank:membank startAddress:startAddress dataLength:dataLength];
    } else {
        [[ASP51NV2 sharedInstance] writeTagWithAccessPassword:accesspassword EPC:epcs memoryBank:membank startAddress:startAddress writeData:data];
    }
}

- (IBAction)eTargetMemoryChanged:(id)sender
{
    self.olDataTitle.text = @"Data (HEX)";
    [self.textView resignFirstResponder];
    [self.textView setKeyboardType:UIKeyboardTypeDefault];
    self.olStartAdress.enabled  = YES;
    self.olLength.enabled       = YES;
    if(self.olTargetMemory.selectedSegmentIndex == 1) {
        //EPC
        self.olStartAdress.text     = @"2";
        self.olLength.text          = @"2";
    }
}

#pragma mark - ASP51NDelegate
- (void)ASP51NV2:(ASP51NV2 *)ASP51NV2 receivedTagOperationData:(NSData *)tagOperationData
{
    dispatch_async(dispatch_get_main_queue(),^{
        NSString *strData;
        strData = [tagOperationData bytesToHexString];
        self.textView.text = strData;
    });
}

- (void)ASP51NV2:(ASP51NV2 *)ASP51NV2 didWriteTagExecutionStatus:(ASP51NV2ExecutionStatus)statusCode
{
    if (statusCode == ASP51NV2ExecutionStatusSuccess) {
        [Utils hiddenLoadingView];
        [Utils showAlert:@"Success" message:@"Writed" view:self];
    } else {
        if (statusCode == ASP51NV2ExecutionStatusOtherCommandExecuted) {
            
        } else {
            [Utils hiddenLoadingView];
        }
        [Utils showAlert:@"Writed Fail" message:[NSString stringWithFormat:@"%x", statusCode] view:self];
    }
}

- (void)ASP51NV2:(ASP51NV2 *)ASP51NV2 didReadTagExecutionStatus:(ASP51NV2ExecutionStatus)statusCode
{
    if (statusCode == ASP51NV2ExecutionStatusSuccess) {
        [Utils hiddenLoadingView];
        [Utils showAlert:@"Success" message:@"Read" view:self];
    } else {
        if (statusCode == ASP51NV2ExecutionStatusOtherCommandExecuted) {
            
        } else {
            [Utils hiddenLoadingView];
        }
        [Utils showAlert:@"Read Fail" message:[NSString stringWithFormat:@"%x", statusCode] view:self];
    }
}

- (void)ASP51NV2:(ASP51NV2 *)ASP51NV2 receivedExecutionStatus:(ASP51NV2ExecutionStatus)statusCode
{
    [Utils showAlert:@"Error" message:[NSString stringWithFormat:@"%x", statusCode] view:self];
}

- (void)ASP51NV2:(ASP51NV2 *)ASP51NV2 changeNetworkState:(ASP51NV2NetworkState)state error:(NSError *)error
{
    switch (state) {
        case ASP51NV2NetworkStateDisconnected:
            [Utils showAlert:@"Fail" message:@"The network connection is lost." view:self];
            break;
        case ASP51NV2NetworkStateError:
            break;
        default:
            break;
    }
}
@end



