//
//  SearchViewController.m
//  P51NV2Demo
//
//  Created by mac on 2019/8/2.
//  Copyright © 2019年 Robin. All rights reserved.
//

#import "SearchViewController.h"
#import "Utils.h"
#import <ASP51NV2SDK/ASP51NV2SDK.h>
@interface SearchViewController ()<ASP51NV2Delegate>
{
    int selectedSession;
}

@end

@implementation SearchViewController

- (void)viewDidLoad {
    [super viewDidLoad];
}

#pragma mark - Lifecycle
- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    [ASP51NV2 sharedInstance].delegate = self;
    
    [self performSelector:@selector(onTickGetSearch)   withObject:nil afterDelay:.4f];
    [Utils showLoadingView:@"" timeOut:df_TIMEOUT_DEFAULT];
}

- (void)viewWillDisappear:(BOOL)animated
{
    [super viewWillDisappear:animated];
    [ASP51NV2 sharedInstance].delegate = nil;
}

#pragma mark - Private Method
- (void)onTickGetSearch
{
//    zzz
//    NSError *error = [[ASP51NV2SDK sharedInstance] getSearchMode];
//    if( error ){
//        NSLog(@"%@\n code = %ld\n%@", NSStringFromSelector(_cmd), error.code, error.userInfo);
//    }
    [[ASP51NV2 sharedInstance] getSearchMode];
}

#pragma mark - ASP51NV2SDKSDK Delegate
- (void)ASP51NV2:(ASP51NV2 *)ASP51NV2 receivedSetSearchMode:(ASP51NV2SearchModeType)searchModel executionStatus:(ASP51NV2ExecutionStatus)statusCode
{
    if (statusCode == ASP51NV2ExecutionStatusSuccess) {
        [Utils hiddenLoadingView];
        selectedSession = searchModel;
        dispatch_async(dispatch_get_main_queue(),^{
            [self.tableView reloadData];
        });
    } else {
        if (statusCode == ASP51NV2ExecutionStatusOtherCommandExecuted) {
            
        } else {
            [Utils hiddenLoadingView];
        }
        [Utils showAlert:@"SearchMode Fail" message:[NSString stringWithFormat:@"%x", statusCode] view:self];
    }
}

- (void)ASP51NV2:(ASP51NV2 *)ASP51NV2 didSetSearchModeExecutionStatus:(ASP51NV2ExecutionStatus)statusCode
{
    if (statusCode == ASP51NV2ExecutionStatusSuccess) {
        [Utils hiddenLoadingView];
        [Utils showAlert:@"Success" message:@"SearchMode changed" view:self];
    } else {
        if (statusCode == ASP51NV2ExecutionStatusOtherCommandExecuted) {
            
        } else {
            [Utils hiddenLoadingView];
        }
        [Utils showAlert:@"SearchMode changed Fail" message:[NSString stringWithFormat:@"%x", statusCode] view:self];
    }
}

- (void)ASP51NV2:(ASP51NV2 *)ASP51NV2 changeNetworkState:(ASP51NV2NetworkState)state error:(NSError *)error
{
    switch (state) {
        case ASP51NV2NetworkStateDisconnected:
            [Utils showAlert:@"Fail" message:@"The network connection is lost." view:self];
            break;
        case ASP51NV2NetworkStateError:
            break;
        default:
            break;
    }
}

- (void)ASP51NV2:(ASP51NV2 *)ASP51NV2 receivedExecutionStatus:(ASP51NV2ExecutionStatus)statusCode
{
    [Utils showAlert:@"Error" message:[NSString stringWithFormat:@"%x", statusCode] view:self];
}

#pragma mark - TableView DataSource
- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return 4;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *CellIdentifier = @"Cell";
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier forIndexPath:indexPath];
    switch (indexPath.row) {
        case 0:
            cell.textLabel.text = @"AUTO_SEARCH";
            break;
        case 1:
            cell.textLabel.text = @"DUAL_TARGET_UAL_TARGET";
            break;
        case 2:
            cell.textLabel.text = @"SINGLE_TARGET_A_TO_B";
            break;
        case 3:
            cell.textLabel.text = @"SINGLE_TARGET_B_TO_A";
            break;
        default:
            break;
    }
    if(selectedSession == indexPath.row)
        cell.accessoryType = UITableViewCellAccessoryCheckmark;
    else
        cell.accessoryType = UITableViewCellAccessoryNone;
    return cell;
}

#pragma mark - TableView Delegate
- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    selectedSession = (int)indexPath.row;
    [self.tableView reloadData];
}

#pragma mark - IBAction
- (IBAction)onClickButtonDone:(id)sender {
    [Utils showLoadingView:@"" timeOut:df_TIMEOUT_DEFAULT];
    ASP51NV2SearchModeType type;
    switch (selectedSession) {
        case 0:
            type = ASP51NV2SearchModeTypeAutoSearch;
            break;
        case 1:
            type = ASP51NV2SearchModeTypeDualTarget;
            break;
        case 2:
            type = ASP51NV2SearchModeTypeSingleTarget_A_TO_B;
            break;
        case 3:
            type = ASP51NV2SearchModeTypeSingleTarget_B_TO_A;
            break;
        default:
            return;
    }
//    NSError *error = [[ASP51NV2SDK sharedInstance] setSearchMode:type];
//    if( error ){
//        NSLog(@"%@\n code = %d\n%@", NSStringFromSelector(_cmd), (int)error.code, error.userInfo);
//    }
    [[ASP51NV2 sharedInstance] setSearchMode:type];
}

/*
#pragma mark - Navigation

// In a storyboard-based application, you will often want to do a little preparation before navigation
- (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender {
    // Get the new view controller using [segue destinationViewController].
    // Pass the selected object to the new view controller.
}
*/

@end
